# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="OptionsBase.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class OptionsBase(object):
    """
    Base container class for all possible options data
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signature_type': 'str',
        'page': 'int',
        'all_pages': 'bool',
        'pages_setup': 'PagesSetup'
    }

    attribute_map = {
        'signature_type': 'SignatureType',
        'page': 'Page',
        'all_pages': 'AllPages',
        'pages_setup': 'PagesSetup'
    }

    def __init__(self, signature_type=None, page=None, all_pages=None, pages_setup=None, **kwargs):  # noqa: E501
        """Initializes new instance of OptionsBase"""  # noqa: E501

        self._signature_type = None
        self._page = None
        self._all_pages = None
        self._pages_setup = None

        if signature_type is not None:
            self.signature_type = signature_type
        if page is not None:
            self.page = page
        if all_pages is not None:
            self.all_pages = all_pages
        if pages_setup is not None:
            self.pages_setup = pages_setup
    
    @property
    def signature_type(self):
        """
        Gets the signature_type.  # noqa: E501

        Specifies the signature type of processing  # noqa: E501

        :return: The signature_type.  # noqa: E501
        :rtype: str
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """
        Sets the signature_type.

        Specifies the signature type of processing  # noqa: E501

        :param signature_type: The signature_type.  # noqa: E501
        :type: str
        """
        if signature_type is None:
            raise ValueError("Invalid value for `signature_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Text", "Image", "Digital", "Barcode", "QRCode", "Stamp", "FormField", "Metadata"]  # noqa: E501
        if not signature_type.isdigit():	
            if signature_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `signature_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(signature_type, allowed_values))
            self._signature_type = signature_type
        else:
            self._signature_type = allowed_values[int(signature_type) if six.PY3 else long(signature_type)]
    
    @property
    def page(self):
        """
        Gets the page.  # noqa: E501

        Gets or sets a document page number for processing. Value is optional  # noqa: E501

        :return: The page.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page.

        Gets or sets a document page number for processing. Value is optional  # noqa: E501

        :param page: The page.  # noqa: E501
        :type: int
        """
        self._page = page
    
    @property
    def all_pages(self):
        """
        Gets the all_pages.  # noqa: E501

        Process all document pages. Type of processing depends on SignatureType For Images Document Type it can be used only for multi-frames images like .tiff  # noqa: E501

        :return: The all_pages.  # noqa: E501
        :rtype: bool
        """
        return self._all_pages

    @all_pages.setter
    def all_pages(self, all_pages):
        """
        Sets the all_pages.

        Process all document pages. Type of processing depends on SignatureType For Images Document Type it can be used only for multi-frames images like .tiff  # noqa: E501

        :param all_pages: The all_pages.  # noqa: E501
        :type: bool
        """
        if all_pages is None:
            raise ValueError("Invalid value for `all_pages`, must not be `None`")  # noqa: E501
        self._all_pages = all_pages
    
    @property
    def pages_setup(self):
        """
        Gets the pages_setup.  # noqa: E501

        Options to specify pages for processing  # noqa: E501

        :return: The pages_setup.  # noqa: E501
        :rtype: PagesSetup
        """
        return self._pages_setup

    @pages_setup.setter
    def pages_setup(self, pages_setup):
        """
        Sets the pages_setup.

        Options to specify pages for processing  # noqa: E501

        :param pages_setup: The pages_setup.  # noqa: E501
        :type: PagesSetup
        """
        self._pages_setup = pages_setup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionsBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import os

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestFileApi(TestContext):
    """FileApi unit tests"""

    def test_delete_file(self):
        # Delete file
        test_file = TestFile.image_signed()
        request = DeleteFileRequest(test_file.folder + test_file.file_name)
        data = self.file_api.delete_file(request)
        # Check
        request = ObjectExistsRequest(test_file.folder + test_file.file_name)        
        data = self.storage_api.object_exists(request)
        self.assertFalse(data.exists)        
        # Upload file
        local_file_path = self.get_test_file_path(test_file)
        request = UploadFileRequest(test_file.folder + test_file.file_name, local_file_path)
        self.file_api.upload_file(request)

    def test_download_file(self):
        test_file = TestFile.image_signed()
        request = DownloadFileRequest(test_file.folder + test_file.file_name)
        data = self.file_api.download_file(request)
        self.assertGreater(os.path.getsize(data), 0)

    def test_copy_move_file(self):
        test_file = TestFile.image_signed()
        full_name = test_file.folder + test_file.file_name        
        # Create temp folder
        request = CreateFolderRequest("temp")
        self.folder_api.create_folder(request)
        # Copy file
        dest_path = "temp/" + full_name
        request = CopyFileRequest(full_name, dest_path)
        self.file_api.copy_file(request)
        # Check copied file
        request = ObjectExistsRequest(dest_path)        
        data = self.storage_api.object_exists(request)
        self.assertTrue(data.exists)
        # Move file
        new_dest_path = "temp/" + full_name.replace("All", "All_1")
        request = MoveFileRequest(dest_path, new_dest_path)
        self.file_api.move_file(request)
        # Check moved file
        request = ObjectExistsRequest(new_dest_path)        
        data = self.storage_api.object_exists(request)
        self.assertTrue(data.exists)      
        # Delete temp folder  
        request = DeleteFolderRequest("temp", None, True)
        self.folder_api.delete_folder(request)        

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PdfDigitalSignatureAppearance.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignatureAppearance

class PdfDigitalSignatureAppearance(SignatureAppearance):
    """
    Describes appearance of Digital Signature are on PDF documents.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background': 'Color',
        'contact_info_label': 'str',
        'date_signed_at_label': 'str',
        'digital_signed_label': 'str',
        'font_family_name': 'str',
        'font_size': 'float',
        'location_label': 'str',
        'reason_label': 'str'
    }

    attribute_map = {
        'background': 'Background',
        'contact_info_label': 'ContactInfoLabel',
        'date_signed_at_label': 'DateSignedAtLabel',
        'digital_signed_label': 'DigitalSignedLabel',
        'font_family_name': 'FontFamilyName',
        'font_size': 'FontSize',
        'location_label': 'LocationLabel',
        'reason_label': 'ReasonLabel'
    }

    def __init__(self, background=None, contact_info_label=None, date_signed_at_label=None, digital_signed_label=None, font_family_name=None, font_size=None, location_label=None, reason_label=None, **kwargs):  # noqa: E501
        """Initializes new instance of PdfDigitalSignatureAppearance"""  # noqa: E501

        self._background = None
        self._contact_info_label = None
        self._date_signed_at_label = None
        self._digital_signed_label = None
        self._font_family_name = None
        self._font_size = None
        self._location_label = None
        self._reason_label = None

        if background is not None:
            self.background = background
        if contact_info_label is not None:
            self.contact_info_label = contact_info_label
        if date_signed_at_label is not None:
            self.date_signed_at_label = date_signed_at_label
        if digital_signed_label is not None:
            self.digital_signed_label = digital_signed_label
        if font_family_name is not None:
            self.font_family_name = font_family_name
        if font_size is not None:
            self.font_size = font_size
        if location_label is not None:
            self.location_label = location_label
        if reason_label is not None:
            self.reason_label = reason_label

        base = super(PdfDigitalSignatureAppearance, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def background(self):
        """
        Gets the background.  # noqa: E501

        Get or set background color of signature appearance. By default the value is SystemColors.Windows  # noqa: E501

        :return: The background.  # noqa: E501
        :rtype: Color
        """
        return self._background

    @background.setter
    def background(self, background):
        """
        Sets the background.

        Get or set background color of signature appearance. By default the value is SystemColors.Windows  # noqa: E501

        :param background: The background.  # noqa: E501
        :type: Color
        """
        self._background = background
    
    @property
    def contact_info_label(self):
        """
        Gets the contact_info_label.  # noqa: E501

        Gets or sets contact info label. Default value: \"Contact\". if this value is empty then no contact label will appear on digital signature area.               # noqa: E501

        :return: The contact_info_label.  # noqa: E501
        :rtype: str
        """
        return self._contact_info_label

    @contact_info_label.setter
    def contact_info_label(self, contact_info_label):
        """
        Sets the contact_info_label.

        Gets or sets contact info label. Default value: \"Contact\". if this value is empty then no contact label will appear on digital signature area.               # noqa: E501

        :param contact_info_label: The contact_info_label.  # noqa: E501
        :type: str
        """
        self._contact_info_label = contact_info_label
    
    @property
    def date_signed_at_label(self):
        """
        Gets the date_signed_at_label.  # noqa: E501

        Gets or sets date signed label. Default value: \"Date\".  # noqa: E501

        :return: The date_signed_at_label.  # noqa: E501
        :rtype: str
        """
        return self._date_signed_at_label

    @date_signed_at_label.setter
    def date_signed_at_label(self, date_signed_at_label):
        """
        Sets the date_signed_at_label.

        Gets or sets date signed label. Default value: \"Date\".  # noqa: E501

        :param date_signed_at_label: The date_signed_at_label.  # noqa: E501
        :type: str
        """
        self._date_signed_at_label = date_signed_at_label
    
    @property
    def digital_signed_label(self):
        """
        Gets the digital_signed_label.  # noqa: E501

        Gets or sets digital signed label. Default value: \"Digitally signed by\".  # noqa: E501

        :return: The digital_signed_label.  # noqa: E501
        :rtype: str
        """
        return self._digital_signed_label

    @digital_signed_label.setter
    def digital_signed_label(self, digital_signed_label):
        """
        Sets the digital_signed_label.

        Gets or sets digital signed label. Default value: \"Digitally signed by\".  # noqa: E501

        :param digital_signed_label: The digital_signed_label.  # noqa: E501
        :type: str
        """
        self._digital_signed_label = digital_signed_label
    
    @property
    def font_family_name(self):
        """
        Gets the font_family_name.  # noqa: E501

        Gets or sets the Font family name to display the labels. Default value is \"Arial\".  # noqa: E501

        :return: The font_family_name.  # noqa: E501
        :rtype: str
        """
        return self._font_family_name

    @font_family_name.setter
    def font_family_name(self, font_family_name):
        """
        Sets the font_family_name.

        Gets or sets the Font family name to display the labels. Default value is \"Arial\".  # noqa: E501

        :param font_family_name: The font_family_name.  # noqa: E501
        :type: str
        """
        self._font_family_name = font_family_name
    
    @property
    def font_size(self):
        """
        Gets the font_size.  # noqa: E501

        Gets or sets the Font size to display the labels. Default value is 10.  # noqa: E501

        :return: The font_size.  # noqa: E501
        :rtype: float
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """
        Sets the font_size.

        Gets or sets the Font size to display the labels. Default value is 10.  # noqa: E501

        :param font_size: The font_size.  # noqa: E501
        :type: float
        """
        self._font_size = font_size
    
    @property
    def location_label(self):
        """
        Gets the location_label.  # noqa: E501

        Gets or sets location label. Default value: \"Location\". if this value is empty then no location label will appear on digital signature area.  # noqa: E501

        :return: The location_label.  # noqa: E501
        :rtype: str
        """
        return self._location_label

    @location_label.setter
    def location_label(self, location_label):
        """
        Sets the location_label.

        Gets or sets location label. Default value: \"Location\". if this value is empty then no location label will appear on digital signature area.  # noqa: E501

        :param location_label: The location_label.  # noqa: E501
        :type: str
        """
        self._location_label = location_label
    
    @property
    def reason_label(self):
        """
        Gets the reason_label.  # noqa: E501

        Gets or sets reason label. Default value: \"Reason\". if this value is empty then no reason label will appear on digital signature area.  # noqa: E501

        :return: The reason_label.  # noqa: E501
        :rtype: str
        """
        return self._reason_label

    @reason_label.setter
    def reason_label(self, reason_label):
        """
        Sets the reason_label.

        Gets or sets reason label. Default value: \"Reason\". if this value is empty then no reason label will appear on digital signature area.  # noqa: E501

        :param reason_label: The reason_label.  # noqa: E501
        :type: str
        """
        self._reason_label = reason_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfDigitalSignatureAppearance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import os

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestInfoApi(TestContext):

    def test_get_supported_file_formats(self):
        response = self.info_api.get_supported_file_formats()
        self.assertGreater(len(response.formats), 0)
        for format in response.formats:
            self.assertFalse(format.file_format == "")
            self.assertFalse(format.extension == "")        

    def test_get_supported_barcodes(self):
        response = self.info_api.get_supported_barcodes()
        self.assertGreater(len(response.barcode_types), 0)
        for format in response.barcode_types:
            self.assertFalse(format.name == "")

    def test_get_supported_qrcodes(self):
        response = self.info_api.get_supported_qr_codes()
        self.assertGreater(len(response.qr_code_types), 0)
        for format in response.qr_code_types:
            self.assertFalse(format.name == "")

    def test_document_info(self):
        test_file = TestFile.pdf_one_page()
        settings = InfoSettings()
        settings.file_info = test_file.ToFileInfo()
        response = self.info_api.get_info(GetInfoRequest(settings))
        self.assertEqual(response.size, 55321)
        self.assertEqual(response.extension, "pdf")
        self.assertEqual(response.file_format, "Portable Document Format File")
        self.assertEqual(response.max_page_height, 792)
        self.assertEqual(response.width_for_max_height, 612)
        self.assertEqual(response.pages_count, 1)
        self.assertEqual(response.file_info.file_path, settings.file_info.file_path)

    def test_get_info_returns_file_not_found(self):
        file_info = TestFile.not_exist().ToFileInfo()
        settings = InfoSettings()
        settings.file_info = file_info
        request = GetInfoRequest(settings)
        with self.assertRaises(ApiException) as context:
            self.info_api.get_info(request)
        self.assertEqual("Can't find file located at 'somefolder\\not-exist.docx'.", context.exception.message)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="SignImageOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignOptions

class SignImageOptions(SignOptions):
    """
    Represents the Image sign options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_file_path': 'str',
        'left': 'int',
        'top': 'int',
        'width': 'int',
        'height': 'int',
        'location_measure_type': 'str',
        'size_measure_type': 'str',
        'rotation_angle': 'int',
        'horizontal_alignment': 'str',
        'vertical_alignment': 'str',
        'margin': 'Padding',
        'margin_measure_type': 'str',
        'transparency': 'float',
        'border': 'BorderLine'
    }

    attribute_map = {
        'image_file_path': 'ImageFilePath',
        'left': 'Left',
        'top': 'Top',
        'width': 'Width',
        'height': 'Height',
        'location_measure_type': 'LocationMeasureType',
        'size_measure_type': 'SizeMeasureType',
        'rotation_angle': 'RotationAngle',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'margin': 'Margin',
        'margin_measure_type': 'MarginMeasureType',
        'transparency': 'Transparency',
        'border': 'Border'
    }

    def __init__(self, image_file_path=None, left=None, top=None, width=None, height=None, location_measure_type=None, size_measure_type=None, rotation_angle=None, horizontal_alignment=None, vertical_alignment=None, margin=None, margin_measure_type=None, transparency=None, border=None, **kwargs):  # noqa: E501
        """Initializes new instance of SignImageOptions"""  # noqa: E501

        self._image_file_path = None
        self._left = None
        self._top = None
        self._width = None
        self._height = None
        self._location_measure_type = None
        self._size_measure_type = None
        self._rotation_angle = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._margin = None
        self._margin_measure_type = None
        self._transparency = None
        self._border = None

        if image_file_path is not None:
            self.image_file_path = image_file_path
        if left is not None:
            self.left = left
        if top is not None:
            self.top = top
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if location_measure_type is not None:
            self.location_measure_type = location_measure_type
        if size_measure_type is not None:
            self.size_measure_type = size_measure_type
        if rotation_angle is not None:
            self.rotation_angle = rotation_angle
        if horizontal_alignment is not None:
            self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment
        if margin is not None:
            self.margin = margin
        if margin_measure_type is not None:
            self.margin_measure_type = margin_measure_type
        if transparency is not None:
            self.transparency = transparency
        if border is not None:
            self.border = border

        base = super(SignImageOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def image_file_path(self):
        """
        Gets the image_file_path.  # noqa: E501

        Gets or sets the signature image file name. This property is used only if ImageStream is not specified  # noqa: E501

        :return: The image_file_path.  # noqa: E501
        :rtype: str
        """
        return self._image_file_path

    @image_file_path.setter
    def image_file_path(self, image_file_path):
        """
        Sets the image_file_path.

        Gets or sets the signature image file name. This property is used only if ImageStream is not specified  # noqa: E501

        :param image_file_path: The image_file_path.  # noqa: E501
        :type: str
        """
        self._image_file_path = image_file_path
    
    @property
    def left(self):
        """
        Gets the left.  # noqa: E501

        Left X position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType). (works if horizontal alignment is not specified). For Spreadsheet documents this property is mutually exclusive with Column property. If Left property is set ColumnNumber will be reset to 0  # noqa: E501

        :return: The left.  # noqa: E501
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        """
        Sets the left.

        Left X position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType). (works if horizontal alignment is not specified). For Spreadsheet documents this property is mutually exclusive with Column property. If Left property is set ColumnNumber will be reset to 0  # noqa: E501

        :param left: The left.  # noqa: E501
        :type: int
        """
        if left is None:
            raise ValueError("Invalid value for `left`, must not be `None`")  # noqa: E501
        self._left = left
    
    @property
    def top(self):
        """
        Gets the top.  # noqa: E501

        Top Y Position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType). (works if vertical alignment is not specified). For Spreadsheet documents this property is mutually exclusive with Row property. If Top property is set RowNumber will be reset to 0  # noqa: E501

        :return: The top.  # noqa: E501
        :rtype: int
        """
        return self._top

    @top.setter
    def top(self, top):
        """
        Sets the top.

        Top Y Position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType). (works if vertical alignment is not specified). For Spreadsheet documents this property is mutually exclusive with Row property. If Top property is set RowNumber will be reset to 0  # noqa: E501

        :param top: The top.  # noqa: E501
        :type: int
        """
        if top is None:
            raise ValueError("Invalid value for `top`, must not be `None`")  # noqa: E501
        self._top = top
    
    @property
    def width(self):
        """
        Gets the width.  # noqa: E501

        Width of Signature on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType)  # noqa: E501

        :return: The width.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width.

        Width of Signature on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType)  # noqa: E501

        :param width: The width.  # noqa: E501
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501
        self._width = width
    
    @property
    def height(self):
        """
        Gets the height.  # noqa: E501

        Height of Signature on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType)  # noqa: E501

        :return: The height.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height.

        Height of Signature on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType)  # noqa: E501

        :param height: The height.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501
        self._height = height
    
    @property
    def location_measure_type(self):
        """
        Gets the location_measure_type.  # noqa: E501

        Measure type (pixels or percent) for Left and Top properties  # noqa: E501

        :return: The location_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._location_measure_type

    @location_measure_type.setter
    def location_measure_type(self, location_measure_type):
        """
        Sets the location_measure_type.

        Measure type (pixels or percent) for Left and Top properties  # noqa: E501

        :param location_measure_type: The location_measure_type.  # noqa: E501
        :type: str
        """
        if location_measure_type is None:
            raise ValueError("Invalid value for `location_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not location_measure_type.isdigit():	
            if location_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `location_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(location_measure_type, allowed_values))
            self._location_measure_type = location_measure_type
        else:
            self._location_measure_type = allowed_values[int(location_measure_type) if six.PY3 else long(location_measure_type)]
    
    @property
    def size_measure_type(self):
        """
        Gets the size_measure_type.  # noqa: E501

        Measure type (pixels or percent) for Width and Height properties  # noqa: E501

        :return: The size_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._size_measure_type

    @size_measure_type.setter
    def size_measure_type(self, size_measure_type):
        """
        Sets the size_measure_type.

        Measure type (pixels or percent) for Width and Height properties  # noqa: E501

        :param size_measure_type: The size_measure_type.  # noqa: E501
        :type: str
        """
        if size_measure_type is None:
            raise ValueError("Invalid value for `size_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not size_measure_type.isdigit():	
            if size_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `size_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(size_measure_type, allowed_values))
            self._size_measure_type = size_measure_type
        else:
            self._size_measure_type = allowed_values[int(size_measure_type) if six.PY3 else long(size_measure_type)]
    
    @property
    def rotation_angle(self):
        """
        Gets the rotation_angle.  # noqa: E501

        Rotation angle of signature on document page (clockwise)  # noqa: E501

        :return: The rotation_angle.  # noqa: E501
        :rtype: int
        """
        return self._rotation_angle

    @rotation_angle.setter
    def rotation_angle(self, rotation_angle):
        """
        Sets the rotation_angle.

        Rotation angle of signature on document page (clockwise)  # noqa: E501

        :param rotation_angle: The rotation_angle.  # noqa: E501
        :type: int
        """
        if rotation_angle is None:
            raise ValueError("Invalid value for `rotation_angle`, must not be `None`")  # noqa: E501
        self._rotation_angle = rotation_angle
    
    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment.  # noqa: E501

        Horizontal alignment of signature on document page  # noqa: E501

        :return: The horizontal_alignment.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment.

        Horizontal alignment of signature on document page  # noqa: E501

        :param horizontal_alignment: The horizontal_alignment.  # noqa: E501
        :type: str
        """
        if horizontal_alignment is None:
            raise ValueError("Invalid value for `horizontal_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Left", "Center", "Right"]  # noqa: E501
        if not horizontal_alignment.isdigit():	
            if horizontal_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `horizontal_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(horizontal_alignment, allowed_values))
            self._horizontal_alignment = horizontal_alignment
        else:
            self._horizontal_alignment = allowed_values[int(horizontal_alignment) if six.PY3 else long(horizontal_alignment)]
    
    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment.  # noqa: E501

        Vertical alignment of signature on document page  # noqa: E501

        :return: The vertical_alignment.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment.

        Vertical alignment of signature on document page  # noqa: E501

        :param vertical_alignment: The vertical_alignment.  # noqa: E501
        :type: str
        """
        if vertical_alignment is None:
            raise ValueError("Invalid value for `vertical_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Top", "Center", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():	
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]
    
    @property
    def margin(self):
        """
        Gets the margin.  # noqa: E501

        Gets or sets the space between Sign and Document edges (works ONLY if horizontal or vertical alignment are specified)  # noqa: E501

        :return: The margin.  # noqa: E501
        :rtype: Padding
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin.

        Gets or sets the space between Sign and Document edges (works ONLY if horizontal or vertical alignment are specified)  # noqa: E501

        :param margin: The margin.  # noqa: E501
        :type: Padding
        """
        self._margin = margin
    
    @property
    def margin_measure_type(self):
        """
        Gets the margin_measure_type.  # noqa: E501

        Gets or sets the measure type (pixels or percent) for Margin  # noqa: E501

        :return: The margin_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._margin_measure_type

    @margin_measure_type.setter
    def margin_measure_type(self, margin_measure_type):
        """
        Sets the margin_measure_type.

        Gets or sets the measure type (pixels or percent) for Margin  # noqa: E501

        :param margin_measure_type: The margin_measure_type.  # noqa: E501
        :type: str
        """
        if margin_measure_type is None:
            raise ValueError("Invalid value for `margin_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not margin_measure_type.isdigit():	
            if margin_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `margin_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(margin_measure_type, allowed_values))
            self._margin_measure_type = margin_measure_type
        else:
            self._margin_measure_type = allowed_values[int(margin_measure_type) if six.PY3 else long(margin_measure_type)]
    
    @property
    def transparency(self):
        """
        Gets the transparency.  # noqa: E501

        Gets or sets the signature transparency(value from 0.0 (opaque) through 1.0 (clear)). Default value is 0 (opaque).  # noqa: E501

        :return: The transparency.  # noqa: E501
        :rtype: float
        """
        return self._transparency

    @transparency.setter
    def transparency(self, transparency):
        """
        Sets the transparency.

        Gets or sets the signature transparency(value from 0.0 (opaque) through 1.0 (clear)). Default value is 0 (opaque).  # noqa: E501

        :param transparency: The transparency.  # noqa: E501
        :type: float
        """
        if transparency is None:
            raise ValueError("Invalid value for `transparency`, must not be `None`")  # noqa: E501
        self._transparency = transparency
    
    @property
    def border(self):
        """
        Gets the border.  # noqa: E501

        Gets or sets the signature border properties  # noqa: E501

        :return: The border.  # noqa: E501
        :rtype: BorderLine
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border.

        Gets or sets the signature border properties  # noqa: E501

        :param border: The border.  # noqa: E501
        :type: BorderLine
        """
        self._border = border

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignImageOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import os

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestSearchBarcode(TestContext):

    def test_search_barcode_image(self):
        test_file = TestFile.image_signed()
        opts = SearchBarcodeOptions()
        self.populate_options(opts)
        settings = SearchSettings()
        settings.file_info = test_file.ToFileInfo()
        settings.options = [opts]
        response = self.sign_api.search_signatures(SearchSignaturesRequest(settings))
        self.check_response([opts], response, test_file)

    def test_search_barcode_pdf(self):
        test_file = TestFile.pdf_signed()
        opts = SearchBarcodeOptions()
        self.populate_options(opts)
        settings = SearchSettings()
        settings.file_info = test_file.ToFileInfo()
        settings.options = [opts]
        response = self.sign_api.search_signatures(SearchSignaturesRequest(settings))
        self.check_response([opts], response, test_file)

    def test_search_barcode_presentation(self):
        test_file = TestFile.presentation_signed()
        opts = SearchBarcodeOptions()
        self.populate_options(opts)
        settings = SearchSettings()
        settings.file_info = test_file.ToFileInfo()
        settings.options = [opts]
        response = self.sign_api.search_signatures(SearchSignaturesRequest(settings))
        self.check_response([opts], response, test_file)

    def test_search_barcode_spreadsheet(self):
        test_file = TestFile.spreadsheet_signed()
        opts = SearchBarcodeOptions()
        self.populate_options(opts)
        settings = SearchSettings()
        settings.file_info = test_file.ToFileInfo()
        settings.options = [opts]
        response = self.sign_api.search_signatures(SearchSignaturesRequest(settings))
        self.check_response([opts], response, test_file)

    def test_search_barcode_wordprocessing(self):
        test_file = TestFile.wordprocessing_signed()
        opts = SearchBarcodeOptions()
        self.populate_options(opts)
        settings = SearchSettings()
        settings.file_info = test_file.ToFileInfo()
        settings.options = [opts]
        response = self.sign_api.search_signatures(SearchSignaturesRequest(settings))
        self.check_response([opts], response, test_file)                        

    @staticmethod
    def populate_options(opts):
        opts.page = 1
        opts.all_pages = True
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps
        opts.signature_type = 'Barcode'
        opts.barcode_type = 'Code39Standard'
        opts.text = '123456789012'
        opts.match_type = 'Contains'
    
    def check_response(self, opts, response, test_file):
        self.assertTrue(response)
        self.assertEqual(response.size, test_file.size)
        self.assertTrue(response.file_info)
        self.assertEqual(response.file_info.file_path, test_file.FilePath())
        self.assertTrue(response.signatures)
        self.assertGreater(len(response.signatures), 0)
        for opt in opts:
            exists = False
            for signature in response.signatures:
                if (signature.signature_type == opt.signature_type and
                    signature.barcode_type == opt.barcode_type and
                    signature.text == opt.text):
                    exists = True
                    break
            self.assertTrue(exists)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestStorageApi(TestContext):
    """StorageApi unit tests"""

    def test_get_disc_usage(self):
        request = GetDiscUsageRequest()
        data = self.storage_api.get_disc_usage(request)
        self.assertGreater(data.total_size, 0)
        self.assertGreater(data.used_size, 0)

    def test_get_storage_exist(self):
        request = StorageExistsRequest("First Storage")
        data = self.storage_api.storage_exists(request)
        self.assertTrue(data.exists) 

    def test_get_file_versions(self):
        test_file = TestFile.image_signed()
        request = GetFileVersionsRequest(test_file.folder + test_file.file_name)        
        data = self.storage_api.get_file_versions(request)
        self.assertGreater(len(data.value), 0)

    def test_get_object_exists(self):
        test_file = TestFile.image_signed()
        request = ObjectExistsRequest(test_file.folder + test_file.file_name)        
        data = self.storage_api.object_exists(request)
        self.assertTrue(data.exists)
        self.assertFalse(data.is_folder)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from groupdocs_signature_cloud.auth import Auth
from groupdocs_signature_cloud.api_client import ApiClient
from groupdocs_signature_cloud.api_exception import ApiException
from groupdocs_signature_cloud.configuration import Configuration

class FileApi(object):
    """
    GroupDocs.Signature Cloud API

    :param configuration: API configuration
    """

    def __init__(self, configuration):
        api_client = ApiClient(configuration)

        self.auth = Auth(configuration, api_client)
        self.api_client = api_client
        self.configuration = configuration

    def close(self):  # noqa: E501
        """
        Closes thread pool. This method should be called when 
        methods are executed asynchronously (is_async=True is passed as parameter)
        and this instance of FileApi is not going to be used any more.
        """
        if self.api_client is not None:
            if(self.api_client.pool is not None):
                self.api_client.pool.close()
                self.api_client.pool.join()
                self.api_client.pool = None

    @classmethod
    def from_keys(cls, app_sid, app_key):
        """
        Initializes new instance of FileApi with API keys

        :param app_sid Application identifier (App SID)
        :param app_key Application private key (App Key)
        """
        configuration = Configuration(app_sid, app_key)
        return FileApi(configuration)

    @classmethod
    def from_config(cls, configuration):
        """
        Initializes new instance of FileApi with configuration options

        :param configuration API configuration
        """
        return FileApi(configuration)

    def copy_file(self, request,**kwargs):  # noqa: E501
        """Copy file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param str src_path: Source file path e.g. '/folder/file.ext' (required)
        :param str dest_path: Destination file path (required)
        :param str src_storage_name: Source storage name
        :param str dest_storage_name: Destination storage name
        :param str version_id: File version ID to copy
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._copy_file_with_http_info(request, **kwargs)  # noqa: E501
        
        self._copy_file_with_http_info(request, **kwargs)  # noqa: E501
        

    def _copy_file_with_http_info(self, request, **kwargs):  # noqa: E501
        """Copy file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param CopyFileRequest request object with parameters
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method copy_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'src_path' is set
        if request.src_path is None:
            raise ValueError("Missing the required parameter `src_path` when calling `copy_file`")  # noqa: E501
        # verify the required parameter 'dest_path' is set
        if request.dest_path is None:
            raise ValueError("Missing the required parameter `dest_path` when calling `copy_file`")  # noqa: E501

        collection_formats = {}
        path = '/signature/storage/file/copy/{srcPath}'
        path_params = {}
        if request.src_path is not None:
            path_params[self.__downcase_first_letter('srcPath')] = request.src_path  # noqa: E501

        query_params = []
        if self.__downcase_first_letter('destPath') in path:
            path = path.replace('{' + self.__downcase_first_letter('destPath' + '}'), request.dest_path if request.dest_path is not None else '')
        else:
            if request.dest_path is not None:
                query_params.append((self.__downcase_first_letter('destPath'), request.dest_path))  # noqa: E501
        if self.__downcase_first_letter('srcStorageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('srcStorageName' + '}'), request.src_storage_name if request.src_storage_name is not None else '')
        else:
            if request.src_storage_name is not None:
                query_params.append((self.__downcase_first_letter('srcStorageName'), request.src_storage_name))  # noqa: E501
        if self.__downcase_first_letter('destStorageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('destStorageName' + '}'), request.dest_storage_name if request.dest_storage_name is not None else '')
        else:
            if request.dest_storage_name is not None:
                query_params.append((self.__downcase_first_letter('destStorageName'), request.dest_storage_name))  # noqa: E501
        if self.__downcase_first_letter('versionId') in path:
            path = path.replace('{' + self.__downcase_first_letter('versionId' + '}'), request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self.__downcase_first_letter('versionId'), request.version_id))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'PUT',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':None,  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def delete_file(self, request,**kwargs):  # noqa: E501
        """Delete file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param str path: File path e.g. '/folder/file.ext' (required)
        :param str storage_name: Storage name
        :param str version_id: File version ID to delete
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._delete_file_with_http_info(request, **kwargs)  # noqa: E501
        
        self._delete_file_with_http_info(request, **kwargs)  # noqa: E501
        

    def _delete_file_with_http_info(self, request, **kwargs):  # noqa: E501
        """Delete file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param DeleteFileRequest request object with parameters
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `delete_file`")  # noqa: E501

        collection_formats = {}
        path = '/signature/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self.__downcase_first_letter('path')] = request.path  # noqa: E501

        query_params = []
        if self.__downcase_first_letter('storageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('storageName' + '}'), request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self.__downcase_first_letter('storageName'), request.storage_name))  # noqa: E501
        if self.__downcase_first_letter('versionId') in path:
            path = path.replace('{' + self.__downcase_first_letter('versionId' + '}'), request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self.__downcase_first_letter('versionId'), request.version_id))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'DELETE',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':None,  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def download_file(self, request,**kwargs):  # noqa: E501
        """Download file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param str path: File path e.g. '/folder/file.ext' (required)
        :param str storage_name: Storage name
        :param str version_id: File version ID to download
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._download_file_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._download_file_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _download_file_with_http_info(self, request, **kwargs):  # noqa: E501
        """Download file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param DownloadFileRequest request object with parameters
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `download_file`")  # noqa: E501

        collection_formats = {}
        path = '/signature/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self.__downcase_first_letter('path')] = request.path  # noqa: E501

        query_params = []
        if self.__downcase_first_letter('storageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('storageName' + '}'), request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self.__downcase_first_letter('storageName'), request.storage_name))  # noqa: E501
        if self.__downcase_first_letter('versionId') in path:
            path = path.replace('{' + self.__downcase_first_letter('versionId' + '}'), request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self.__downcase_first_letter('versionId'), request.version_id))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['multipart/form-data'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'GET',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'file',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def move_file(self, request,**kwargs):  # noqa: E501
        """Move file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param str src_path: Source file path e.g. '/src.ext' (required)
        :param str dest_path: Destination file path e.g. '/dest.ext' (required)
        :param str src_storage_name: Source storage name
        :param str dest_storage_name: Destination storage name
        :param str version_id: File version ID to move
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._move_file_with_http_info(request, **kwargs)  # noqa: E501
        
        self._move_file_with_http_info(request, **kwargs)  # noqa: E501
        

    def _move_file_with_http_info(self, request, **kwargs):  # noqa: E501
        """Move file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param MoveFileRequest request object with parameters
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method move_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'src_path' is set
        if request.src_path is None:
            raise ValueError("Missing the required parameter `src_path` when calling `move_file`")  # noqa: E501
        # verify the required parameter 'dest_path' is set
        if request.dest_path is None:
            raise ValueError("Missing the required parameter `dest_path` when calling `move_file`")  # noqa: E501

        collection_formats = {}
        path = '/signature/storage/file/move/{srcPath}'
        path_params = {}
        if request.src_path is not None:
            path_params[self.__downcase_first_letter('srcPath')] = request.src_path  # noqa: E501

        query_params = []
        if self.__downcase_first_letter('destPath') in path:
            path = path.replace('{' + self.__downcase_first_letter('destPath' + '}'), request.dest_path if request.dest_path is not None else '')
        else:
            if request.dest_path is not None:
                query_params.append((self.__downcase_first_letter('destPath'), request.dest_path))  # noqa: E501
        if self.__downcase_first_letter('srcStorageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('srcStorageName' + '}'), request.src_storage_name if request.src_storage_name is not None else '')
        else:
            if request.src_storage_name is not None:
                query_params.append((self.__downcase_first_letter('srcStorageName'), request.src_storage_name))  # noqa: E501
        if self.__downcase_first_letter('destStorageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('destStorageName' + '}'), request.dest_storage_name if request.dest_storage_name is not None else '')
        else:
            if request.dest_storage_name is not None:
                query_params.append((self.__downcase_first_letter('destStorageName'), request.dest_storage_name))  # noqa: E501
        if self.__downcase_first_letter('versionId') in path:
            path = path.replace('{' + self.__downcase_first_letter('versionId' + '}'), request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self.__downcase_first_letter('versionId'), request.version_id))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'PUT',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':None,  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def upload_file(self, request,**kwargs):  # noqa: E501
        """Upload file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param str path: Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.              (required)
        :param file file: File to upload (required)
        :param str storage_name: Storage name
        :return: FilesUploadResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._upload_file_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._upload_file_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _upload_file_with_http_info(self, request, **kwargs):  # noqa: E501
        """Upload file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param UploadFileRequest request object with parameters
        :return: FilesUploadResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `upload_file`")  # noqa: E501
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `upload_file`")  # noqa: E501

        collection_formats = {}
        path = '/signature/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self.__downcase_first_letter('path')] = request.path  # noqa: E501

        query_params = []
        if self.__downcase_first_letter('storageName') in path:
            path = path.replace('{' + self.__downcase_first_letter('storageName' + '}'), request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self.__downcase_first_letter('storageName'), request.storage_name))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self.__downcase_first_letter('File'), request.file))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'PUT',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'FilesUploadResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def __downcase_first_letter(self, s):
        if len(s) == 0:
            return str
        else:
            return s[0].lower() + s[1:]

# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="copy_file_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class CopyFileRequest(object):
    """
    Request model for copy_file operation.
    :param src_path Source file path e.g. '/folder/file.ext'
    :param dest_path Destination file path
    :param src_storage_name Source storage name
    :param dest_storage_name Destination storage name
    :param version_id File version ID to copy
    """

    def __init__(self, src_path, dest_path, src_storage_name=None, dest_storage_name=None, version_id=None):
        """Initializes new instance of CopyFileRequest."""  # noqa: E501
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name
        self.version_id = version_id
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="delete_file_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class DeleteFileRequest(object):
    """
    Request model for delete_file operation.
    :param path File path e.g. '/folder/file.ext'
    :param storage_name Storage name
    :param version_id File version ID to delete
    """

    def __init__(self, path, storage_name=None, version_id=None):
        """Initializes new instance of DeleteFileRequest."""  # noqa: E501
        self.path = path
        self.storage_name = storage_name
        self.version_id = version_id
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="download_file_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class DownloadFileRequest(object):
    """
    Request model for download_file operation.
    :param path File path e.g. '/folder/file.ext'
    :param storage_name Storage name
    :param version_id File version ID to download
    """

    def __init__(self, path, storage_name=None, version_id=None):
        """Initializes new instance of DownloadFileRequest."""  # noqa: E501
        self.path = path
        self.storage_name = storage_name
        self.version_id = version_id
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="move_file_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class MoveFileRequest(object):
    """
    Request model for move_file operation.
    :param src_path Source file path e.g. '/src.ext'
    :param dest_path Destination file path e.g. '/dest.ext'
    :param src_storage_name Source storage name
    :param dest_storage_name Destination storage name
    :param version_id File version ID to move
    """

    def __init__(self, src_path, dest_path, src_storage_name=None, dest_storage_name=None, version_id=None):
        """Initializes new instance of MoveFileRequest."""  # noqa: E501
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name
        self.version_id = version_id
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="upload_file_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class UploadFileRequest(object):
    """
    Request model for upload_file operation.
    :param path Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.             
    :param file File to upload
    :param storage_name Storage name
    """

    def __init__(self, path, file, storage_name=None):
        """Initializes new instance of UploadFileRequest."""  # noqa: E501
        self.path = path
        self.file = file
        self.storage_name = storage_name



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PdfTextStickerAppearance.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignatureAppearance

class PdfTextStickerAppearance(SignatureAppearance):
    """
    Describes appearance of PDF text annotation sticker object and pop-up window of sticker.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contents': 'str',
        'icon': 'str',
        'opened': 'bool',
        'subject': 'str',
        'title': 'str'
    }

    attribute_map = {
        'contents': 'Contents',
        'icon': 'Icon',
        'opened': 'Opened',
        'subject': 'Subject',
        'title': 'Title'
    }

    def __init__(self, contents=None, icon=None, opened=None, subject=None, title=None, **kwargs):  # noqa: E501
        """Initializes new instance of PdfTextStickerAppearance"""  # noqa: E501

        self._contents = None
        self._icon = None
        self._opened = None
        self._subject = None
        self._title = None

        if contents is not None:
            self.contents = contents
        if icon is not None:
            self.icon = icon
        if opened is not None:
            self.opened = opened
        if subject is not None:
            self.subject = subject
        if title is not None:
            self.title = title

        base = super(PdfTextStickerAppearance, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def contents(self):
        """
        Gets the contents.  # noqa: E501

        Gets or sets the contents of pop-up window.  # noqa: E501

        :return: The contents.  # noqa: E501
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents.

        Gets or sets the contents of pop-up window.  # noqa: E501

        :param contents: The contents.  # noqa: E501
        :type: str
        """
        self._contents = contents
    
    @property
    def icon(self):
        """
        Gets the icon.  # noqa: E501

        Gets or sets the icon of sticker.  # noqa: E501

        :return: The icon.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon.

        Gets or sets the icon of sticker.  # noqa: E501

        :param icon: The icon.  # noqa: E501
        :type: str
        """
        if icon is None:
            raise ValueError("Invalid value for `icon`, must not be `None`")  # noqa: E501
        allowed_values = ["Note", "Comment", "Key", "Help", "NewParagraph", "Paragraph", "Insert", "Check", "Cross", "Circle", "Star"]  # noqa: E501
        if not icon.isdigit():	
            if icon not in allowed_values:
                raise ValueError(
                    "Invalid value for `icon` ({0}), must be one of {1}"  # noqa: E501
                    .format(icon, allowed_values))
            self._icon = icon
        else:
            self._icon = allowed_values[int(icon) if six.PY3 else long(icon)]
    
    @property
    def opened(self):
        """
        Gets the opened.  # noqa: E501

        Setup if sticker pop-up window will be opened by default.  # noqa: E501

        :return: The opened.  # noqa: E501
        :rtype: bool
        """
        return self._opened

    @opened.setter
    def opened(self, opened):
        """
        Sets the opened.

        Setup if sticker pop-up window will be opened by default.  # noqa: E501

        :param opened: The opened.  # noqa: E501
        :type: bool
        """
        if opened is None:
            raise ValueError("Invalid value for `opened`, must not be `None`")  # noqa: E501
        self._opened = opened
    
    @property
    def subject(self):
        """
        Gets the subject.  # noqa: E501

        Gets or sets subject.  # noqa: E501

        :return: The subject.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject.

        Gets or sets subject.  # noqa: E501

        :param subject: The subject.  # noqa: E501
        :type: str
        """
        self._subject = subject
    
    @property
    def title(self):
        """
        Gets the title.  # noqa: E501

        Gets or sets title of pop-up window.  # noqa: E501

        :return: The title.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title.

        Gets or sets title of pop-up window.  # noqa: E501

        :param title: The title.  # noqa: E501
        :type: str
        """
        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfTextStickerAppearance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="SignTextOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignOptions

class SignTextOptions(SignOptions):
    """
    Base container class for signature options data
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'left': 'int',
        'top': 'int',
        'width': 'int',
        'height': 'int',
        'location_measure_type': 'str',
        'size_measure_type': 'str',
        'stretch': 'str',
        'rotation_angle': 'int',
        'horizontal_alignment': 'str',
        'vertical_alignment': 'str',
        'margin': 'Padding',
        'margin_measure_type': 'str',
        'text': 'str',
        'font': 'SignatureFont',
        'fore_color': 'Color',
        'background_color': 'Color',
        'background_brush': 'Brush',
        'border': 'BorderLine',
        'text_horizontal_alignment': 'str',
        'text_vertical_alignment': 'str',
        'z_order': 'int',
        'native': 'bool'
    }

    attribute_map = {
        'left': 'Left',
        'top': 'Top',
        'width': 'Width',
        'height': 'Height',
        'location_measure_type': 'LocationMeasureType',
        'size_measure_type': 'SizeMeasureType',
        'stretch': 'Stretch',
        'rotation_angle': 'RotationAngle',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'margin': 'Margin',
        'margin_measure_type': 'MarginMeasureType',
        'text': 'Text',
        'font': 'Font',
        'fore_color': 'ForeColor',
        'background_color': 'BackgroundColor',
        'background_brush': 'BackgroundBrush',
        'border': 'Border',
        'text_horizontal_alignment': 'TextHorizontalAlignment',
        'text_vertical_alignment': 'TextVerticalAlignment',
        'z_order': 'ZOrder',
        'native': 'Native'
    }

    def __init__(self, left=None, top=None, width=None, height=None, location_measure_type=None, size_measure_type=None, stretch=None, rotation_angle=None, horizontal_alignment=None, vertical_alignment=None, margin=None, margin_measure_type=None, text=None, font=None, fore_color=None, background_color=None, background_brush=None, border=None, text_horizontal_alignment=None, text_vertical_alignment=None, z_order=None, native=None, **kwargs):  # noqa: E501
        """Initializes new instance of SignTextOptions"""  # noqa: E501

        self._left = None
        self._top = None
        self._width = None
        self._height = None
        self._location_measure_type = None
        self._size_measure_type = None
        self._stretch = None
        self._rotation_angle = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._margin = None
        self._margin_measure_type = None
        self._text = None
        self._font = None
        self._fore_color = None
        self._background_color = None
        self._background_brush = None
        self._border = None
        self._text_horizontal_alignment = None
        self._text_vertical_alignment = None
        self._z_order = None
        self._native = None

        if left is not None:
            self.left = left
        if top is not None:
            self.top = top
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if location_measure_type is not None:
            self.location_measure_type = location_measure_type
        if size_measure_type is not None:
            self.size_measure_type = size_measure_type
        if stretch is not None:
            self.stretch = stretch
        if rotation_angle is not None:
            self.rotation_angle = rotation_angle
        if horizontal_alignment is not None:
            self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment
        if margin is not None:
            self.margin = margin
        if margin_measure_type is not None:
            self.margin_measure_type = margin_measure_type
        if text is not None:
            self.text = text
        if font is not None:
            self.font = font
        if fore_color is not None:
            self.fore_color = fore_color
        if background_color is not None:
            self.background_color = background_color
        if background_brush is not None:
            self.background_brush = background_brush
        if border is not None:
            self.border = border
        if text_horizontal_alignment is not None:
            self.text_horizontal_alignment = text_horizontal_alignment
        if text_vertical_alignment is not None:
            self.text_vertical_alignment = text_vertical_alignment
        if z_order is not None:
            self.z_order = z_order
        if native is not None:
            self.native = native

        base = super(SignTextOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def left(self):
        """
        Gets the left.  # noqa: E501

        Left X position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType property)  # noqa: E501

        :return: The left.  # noqa: E501
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        """
        Sets the left.

        Left X position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType property)  # noqa: E501

        :param left: The left.  # noqa: E501
        :type: int
        """
        if left is None:
            raise ValueError("Invalid value for `left`, must not be `None`")  # noqa: E501
        self._left = left
    
    @property
    def top(self):
        """
        Gets the top.  # noqa: E501

        Top Y Position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType property)  # noqa: E501

        :return: The top.  # noqa: E501
        :rtype: int
        """
        return self._top

    @top.setter
    def top(self, top):
        """
        Sets the top.

        Top Y Position of Signature on Document Page in Measure values (pixels or percent see MeasureType LocationMeasureType property)  # noqa: E501

        :param top: The top.  # noqa: E501
        :type: int
        """
        if top is None:
            raise ValueError("Invalid value for `top`, must not be `None`")  # noqa: E501
        self._top = top
    
    @property
    def width(self):
        """
        Gets the width.  # noqa: E501

        Width of Signature area on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType property)  # noqa: E501

        :return: The width.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width.

        Width of Signature area on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType property)  # noqa: E501

        :param width: The width.  # noqa: E501
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501
        self._width = width
    
    @property
    def height(self):
        """
        Gets the height.  # noqa: E501

        Height of Signature are on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType property)  # noqa: E501

        :return: The height.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height.

        Height of Signature are on Document Page in Measure values (pixels or percent see MeasureType SizeMeasureType property)  # noqa: E501

        :param height: The height.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501
        self._height = height
    
    @property
    def location_measure_type(self):
        """
        Gets the location_measure_type.  # noqa: E501

        Measure type (pixels or percent) for Left and Top properties  # noqa: E501

        :return: The location_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._location_measure_type

    @location_measure_type.setter
    def location_measure_type(self, location_measure_type):
        """
        Sets the location_measure_type.

        Measure type (pixels or percent) for Left and Top properties  # noqa: E501

        :param location_measure_type: The location_measure_type.  # noqa: E501
        :type: str
        """
        if location_measure_type is None:
            raise ValueError("Invalid value for `location_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not location_measure_type.isdigit():	
            if location_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `location_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(location_measure_type, allowed_values))
            self._location_measure_type = location_measure_type
        else:
            self._location_measure_type = allowed_values[int(location_measure_type) if six.PY3 else long(location_measure_type)]
    
    @property
    def size_measure_type(self):
        """
        Gets the size_measure_type.  # noqa: E501

        Measure type (pixels or percent) for Width and Height properties  # noqa: E501

        :return: The size_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._size_measure_type

    @size_measure_type.setter
    def size_measure_type(self, size_measure_type):
        """
        Sets the size_measure_type.

        Measure type (pixels or percent) for Width and Height properties  # noqa: E501

        :param size_measure_type: The size_measure_type.  # noqa: E501
        :type: str
        """
        if size_measure_type is None:
            raise ValueError("Invalid value for `size_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not size_measure_type.isdigit():	
            if size_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `size_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(size_measure_type, allowed_values))
            self._size_measure_type = size_measure_type
        else:
            self._size_measure_type = allowed_values[int(size_measure_type) if six.PY3 else long(size_measure_type)]
    
    @property
    def stretch(self):
        """
        Gets the stretch.  # noqa: E501

        Stretch mode on document page  # noqa: E501

        :return: The stretch.  # noqa: E501
        :rtype: str
        """
        return self._stretch

    @stretch.setter
    def stretch(self, stretch):
        """
        Sets the stretch.

        Stretch mode on document page  # noqa: E501

        :param stretch: The stretch.  # noqa: E501
        :type: str
        """
        if stretch is None:
            raise ValueError("Invalid value for `stretch`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "PageWidth", "PageHeight", "PageArea"]  # noqa: E501
        if not stretch.isdigit():	
            if stretch not in allowed_values:
                raise ValueError(
                    "Invalid value for `stretch` ({0}), must be one of {1}"  # noqa: E501
                    .format(stretch, allowed_values))
            self._stretch = stretch
        else:
            self._stretch = allowed_values[int(stretch) if six.PY3 else long(stretch)]
    
    @property
    def rotation_angle(self):
        """
        Gets the rotation_angle.  # noqa: E501

        Rotation angle of signature on document page (clockwise)  # noqa: E501

        :return: The rotation_angle.  # noqa: E501
        :rtype: int
        """
        return self._rotation_angle

    @rotation_angle.setter
    def rotation_angle(self, rotation_angle):
        """
        Sets the rotation_angle.

        Rotation angle of signature on document page (clockwise)  # noqa: E501

        :param rotation_angle: The rotation_angle.  # noqa: E501
        :type: int
        """
        if rotation_angle is None:
            raise ValueError("Invalid value for `rotation_angle`, must not be `None`")  # noqa: E501
        self._rotation_angle = rotation_angle
    
    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment.  # noqa: E501

        Horizontal alignment of signature on document page  # noqa: E501

        :return: The horizontal_alignment.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment.

        Horizontal alignment of signature on document page  # noqa: E501

        :param horizontal_alignment: The horizontal_alignment.  # noqa: E501
        :type: str
        """
        if horizontal_alignment is None:
            raise ValueError("Invalid value for `horizontal_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Left", "Center", "Right"]  # noqa: E501
        if not horizontal_alignment.isdigit():	
            if horizontal_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `horizontal_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(horizontal_alignment, allowed_values))
            self._horizontal_alignment = horizontal_alignment
        else:
            self._horizontal_alignment = allowed_values[int(horizontal_alignment) if six.PY3 else long(horizontal_alignment)]
    
    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment.  # noqa: E501

        Vertical alignment of signature on document page  # noqa: E501

        :return: The vertical_alignment.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment.

        Vertical alignment of signature on document page  # noqa: E501

        :param vertical_alignment: The vertical_alignment.  # noqa: E501
        :type: str
        """
        if vertical_alignment is None:
            raise ValueError("Invalid value for `vertical_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Top", "Center", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():	
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]
    
    @property
    def margin(self):
        """
        Gets the margin.  # noqa: E501

        Gets or sets the space between Sign and Document edges (works ONLY if horizontal or vertical alignment are specified)  # noqa: E501

        :return: The margin.  # noqa: E501
        :rtype: Padding
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin.

        Gets or sets the space between Sign and Document edges (works ONLY if horizontal or vertical alignment are specified)  # noqa: E501

        :param margin: The margin.  # noqa: E501
        :type: Padding
        """
        self._margin = margin
    
    @property
    def margin_measure_type(self):
        """
        Gets the margin_measure_type.  # noqa: E501

        Gets or sets the measure type (pixels or percent) for Margin  # noqa: E501

        :return: The margin_measure_type.  # noqa: E501
        :rtype: str
        """
        return self._margin_measure_type

    @margin_measure_type.setter
    def margin_measure_type(self, margin_measure_type):
        """
        Sets the margin_measure_type.

        Gets or sets the measure type (pixels or percent) for Margin  # noqa: E501

        :param margin_measure_type: The margin_measure_type.  # noqa: E501
        :type: str
        """
        if margin_measure_type is None:
            raise ValueError("Invalid value for `margin_measure_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Pixels", "Percents", "Millimeters"]  # noqa: E501
        if not margin_measure_type.isdigit():	
            if margin_measure_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `margin_measure_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(margin_measure_type, allowed_values))
            self._margin_measure_type = margin_measure_type
        else:
            self._margin_measure_type = allowed_values[int(margin_measure_type) if six.PY3 else long(margin_measure_type)]
    
    @property
    def text(self):
        """
        Gets the text.  # noqa: E501

        Text of signature  # noqa: E501

        :return: The text.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text.

        Text of signature  # noqa: E501

        :param text: The text.  # noqa: E501
        :type: str
        """
        self._text = text
    
    @property
    def font(self):
        """
        Gets the font.  # noqa: E501

        Gets or sets the font of signature  # noqa: E501

        :return: The font.  # noqa: E501
        :rtype: SignatureFont
        """
        return self._font

    @font.setter
    def font(self, font):
        """
        Sets the font.

        Gets or sets the font of signature  # noqa: E501

        :param font: The font.  # noqa: E501
        :type: SignatureFont
        """
        self._font = font
    
    @property
    def fore_color(self):
        """
        Gets the fore_color.  # noqa: E501

        Gets or sets the fore color of signature  # noqa: E501

        :return: The fore_color.  # noqa: E501
        :rtype: Color
        """
        return self._fore_color

    @fore_color.setter
    def fore_color(self, fore_color):
        """
        Sets the fore_color.

        Gets or sets the fore color of signature  # noqa: E501

        :param fore_color: The fore_color.  # noqa: E501
        :type: Color
        """
        self._fore_color = fore_color
    
    @property
    def background_color(self):
        """
        Gets the background_color.  # noqa: E501

        Gets or sets the background color of signature  # noqa: E501

        :return: The background_color.  # noqa: E501
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color.

        Gets or sets the background color of signature  # noqa: E501

        :param background_color: The background_color.  # noqa: E501
        :type: Color
        """
        self._background_color = background_color
    
    @property
    def background_brush(self):
        """
        Gets the background_brush.  # noqa: E501

        Gets or sets the signature background brush. Value by default is null.  If this property has a value it will be used instead BackgroundBrush property. For Spreadsheet documents TextStamp implementation RadialGradientBrush is not applicable, it is replaced by LinearGradientBrush. Spreadsheets, Images, Presentations It is not used for Watermark implementation. PDF For Stamp implementation LinearGradientBrush (ColorStart) and RadialGradientBrush (ColorInner) are used as SolidBrush. PDF It is not used for Annotation, Sticker, TextToFormField and Watermark implementations. Presentations For TextStamp implementation RadialGradientBrush is not applicable, it is replaced by LinearGradientBrush. Word Processing For TextStamp implementation LinearGradientBrush (ColorStart) and RadialGradientBrush (ColorInner) are used as SolidBrush. Word Processing It is not used for TextToFormField and Watermark implementations  # noqa: E501

        :return: The background_brush.  # noqa: E501
        :rtype: Brush
        """
        return self._background_brush

    @background_brush.setter
    def background_brush(self, background_brush):
        """
        Sets the background_brush.

        Gets or sets the signature background brush. Value by default is null.  If this property has a value it will be used instead BackgroundBrush property. For Spreadsheet documents TextStamp implementation RadialGradientBrush is not applicable, it is replaced by LinearGradientBrush. Spreadsheets, Images, Presentations It is not used for Watermark implementation. PDF For Stamp implementation LinearGradientBrush (ColorStart) and RadialGradientBrush (ColorInner) are used as SolidBrush. PDF It is not used for Annotation, Sticker, TextToFormField and Watermark implementations. Presentations For TextStamp implementation RadialGradientBrush is not applicable, it is replaced by LinearGradientBrush. Word Processing For TextStamp implementation LinearGradientBrush (ColorStart) and RadialGradientBrush (ColorInner) are used as SolidBrush. Word Processing It is not used for TextToFormField and Watermark implementations  # noqa: E501

        :param background_brush: The background_brush.  # noqa: E501
        :type: Brush
        """
        self._background_brush = background_brush
    
    @property
    def border(self):
        """
        Gets the border.  # noqa: E501

        Gets or sets the signature border properties  # noqa: E501

        :return: The border.  # noqa: E501
        :rtype: BorderLine
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border.

        Gets or sets the signature border properties  # noqa: E501

        :param border: The border.  # noqa: E501
        :type: BorderLine
        """
        self._border = border
    
    @property
    def text_horizontal_alignment(self):
        """
        Gets the text_horizontal_alignment.  # noqa: E501

        Horizontal alignment of text inside a signature  # noqa: E501

        :return: The text_horizontal_alignment.  # noqa: E501
        :rtype: str
        """
        return self._text_horizontal_alignment

    @text_horizontal_alignment.setter
    def text_horizontal_alignment(self, text_horizontal_alignment):
        """
        Sets the text_horizontal_alignment.

        Horizontal alignment of text inside a signature  # noqa: E501

        :param text_horizontal_alignment: The text_horizontal_alignment.  # noqa: E501
        :type: str
        """
        if text_horizontal_alignment is None:
            raise ValueError("Invalid value for `text_horizontal_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["Left", "Center", "Right"]  # noqa: E501
        if not text_horizontal_alignment.isdigit():	
            if text_horizontal_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_horizontal_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_horizontal_alignment, allowed_values))
            self._text_horizontal_alignment = text_horizontal_alignment
        else:
            self._text_horizontal_alignment = allowed_values[int(text_horizontal_alignment) if six.PY3 else long(text_horizontal_alignment)]
    
    @property
    def text_vertical_alignment(self):
        """
        Gets the text_vertical_alignment.  # noqa: E501

        Vertical alignment of text inside a signature  # noqa: E501

        :return: The text_vertical_alignment.  # noqa: E501
        :rtype: str
        """
        return self._text_vertical_alignment

    @text_vertical_alignment.setter
    def text_vertical_alignment(self, text_vertical_alignment):
        """
        Sets the text_vertical_alignment.

        Vertical alignment of text inside a signature  # noqa: E501

        :param text_vertical_alignment: The text_vertical_alignment.  # noqa: E501
        :type: str
        """
        if text_vertical_alignment is None:
            raise ValueError("Invalid value for `text_vertical_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["Top", "Center", "Bottom"]  # noqa: E501
        if not text_vertical_alignment.isdigit():	
            if text_vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_vertical_alignment, allowed_values))
            self._text_vertical_alignment = text_vertical_alignment
        else:
            self._text_vertical_alignment = allowed_values[int(text_vertical_alignment) if six.PY3 else long(text_vertical_alignment)]
    
    @property
    def z_order(self):
        """
        Gets the z_order.  # noqa: E501

        Gets or sets the Z-order position of text signature. Determines the display order of overlapping signatures.               # noqa: E501

        :return: The z_order.  # noqa: E501
        :rtype: int
        """
        return self._z_order

    @z_order.setter
    def z_order(self, z_order):
        """
        Sets the z_order.

        Gets or sets the Z-order position of text signature. Determines the display order of overlapping signatures.               # noqa: E501

        :param z_order: The z_order.  # noqa: E501
        :type: int
        """
        if z_order is None:
            raise ValueError("Invalid value for `z_order`, must not be `None`")  # noqa: E501
        self._z_order = z_order
    
    @property
    def native(self):
        """
        Gets the native.  # noqa: E501

        Gets or sets the native attribute. If it is set document specific signatures could be used. Native text watermark for WordProcessing documents is different than regular, for example.               # noqa: E501

        :return: The native.  # noqa: E501
        :rtype: bool
        """
        return self._native

    @native.setter
    def native(self, native):
        """
        Sets the native.

        Gets or sets the native attribute. If it is set document specific signatures could be used. Native text watermark for WordProcessing documents is different than regular, for example.               # noqa: E501

        :param native: The native.  # noqa: E501
        :type: bool
        """
        if native is None:
            raise ValueError("Invalid value for `native`, must not be `None`")  # noqa: E501
        self._native = native

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignTextOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="SignStampOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignImageOptions

class SignStampOptions(SignImageOptions):
    """
    Represents the Stamp signature options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'outer_lines': 'list[StampLine]',
        'inner_lines': 'list[StampLine]',
        'background_color': 'Color',
        'background_brush': 'Brush',
        'background_color_crop_type': 'str',
        'background_image_crop_type': 'str'
    }

    attribute_map = {
        'outer_lines': 'OuterLines',
        'inner_lines': 'InnerLines',
        'background_color': 'BackgroundColor',
        'background_brush': 'BackgroundBrush',
        'background_color_crop_type': 'BackgroundColorCropType',
        'background_image_crop_type': 'BackgroundImageCropType'
    }

    def __init__(self, outer_lines=None, inner_lines=None, background_color=None, background_brush=None, background_color_crop_type=None, background_image_crop_type=None, **kwargs):  # noqa: E501
        """Initializes new instance of SignStampOptions"""  # noqa: E501

        self._outer_lines = None
        self._inner_lines = None
        self._background_color = None
        self._background_brush = None
        self._background_color_crop_type = None
        self._background_image_crop_type = None

        if outer_lines is not None:
            self.outer_lines = outer_lines
        if inner_lines is not None:
            self.inner_lines = inner_lines
        if background_color is not None:
            self.background_color = background_color
        if background_brush is not None:
            self.background_brush = background_brush
        if background_color_crop_type is not None:
            self.background_color_crop_type = background_color_crop_type
        if background_image_crop_type is not None:
            self.background_image_crop_type = background_image_crop_type

        base = super(SignStampOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def outer_lines(self):
        """
        Gets the outer_lines.  # noqa: E501

        List of Outer Lines rendered as concentric circles  # noqa: E501

        :return: The outer_lines.  # noqa: E501
        :rtype: list[StampLine]
        """
        return self._outer_lines

    @outer_lines.setter
    def outer_lines(self, outer_lines):
        """
        Sets the outer_lines.

        List of Outer Lines rendered as concentric circles  # noqa: E501

        :param outer_lines: The outer_lines.  # noqa: E501
        :type: list[StampLine]
        """
        self._outer_lines = outer_lines
    
    @property
    def inner_lines(self):
        """
        Gets the inner_lines.  # noqa: E501

        List of Inner Lines rendered as set of rectangles  # noqa: E501

        :return: The inner_lines.  # noqa: E501
        :rtype: list[StampLine]
        """
        return self._inner_lines

    @inner_lines.setter
    def inner_lines(self, inner_lines):
        """
        Sets the inner_lines.

        List of Inner Lines rendered as set of rectangles  # noqa: E501

        :param inner_lines: The inner_lines.  # noqa: E501
        :type: list[StampLine]
        """
        self._inner_lines = inner_lines
    
    @property
    def background_color(self):
        """
        Gets the background_color.  # noqa: E501

        Gets or sets the background color of signature  # noqa: E501

        :return: The background_color.  # noqa: E501
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color.

        Gets or sets the background color of signature  # noqa: E501

        :param background_color: The background_color.  # noqa: E501
        :type: Color
        """
        self._background_color = background_color
    
    @property
    def background_brush(self):
        """
        Gets the background_brush.  # noqa: E501

        Gets or sets the signature background brush. Value by default is null.  When property has a value it is used instead BackgroundBrush property  # noqa: E501

        :return: The background_brush.  # noqa: E501
        :rtype: Brush
        """
        return self._background_brush

    @background_brush.setter
    def background_brush(self, background_brush):
        """
        Sets the background_brush.

        Gets or sets the signature background brush. Value by default is null.  When property has a value it is used instead BackgroundBrush property  # noqa: E501

        :param background_brush: The background_brush.  # noqa: E501
        :type: Brush
        """
        self._background_brush = background_brush
    
    @property
    def background_color_crop_type(self):
        """
        Gets the background_color_crop_type.  # noqa: E501

        Gets or sets the background color crop type of signature  # noqa: E501

        :return: The background_color_crop_type.  # noqa: E501
        :rtype: str
        """
        return self._background_color_crop_type

    @background_color_crop_type.setter
    def background_color_crop_type(self, background_color_crop_type):
        """
        Sets the background_color_crop_type.

        Gets or sets the background color crop type of signature  # noqa: E501

        :param background_color_crop_type: The background_color_crop_type.  # noqa: E501
        :type: str
        """
        if background_color_crop_type is None:
            raise ValueError("Invalid value for `background_color_crop_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "OuterArea", "MiddleArea", "InnerArea"]  # noqa: E501
        if not background_color_crop_type.isdigit():	
            if background_color_crop_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `background_color_crop_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(background_color_crop_type, allowed_values))
            self._background_color_crop_type = background_color_crop_type
        else:
            self._background_color_crop_type = allowed_values[int(background_color_crop_type) if six.PY3 else long(background_color_crop_type)]
    
    @property
    def background_image_crop_type(self):
        """
        Gets the background_image_crop_type.  # noqa: E501

        Gets or sets the background image crop type of signature  # noqa: E501

        :return: The background_image_crop_type.  # noqa: E501
        :rtype: str
        """
        return self._background_image_crop_type

    @background_image_crop_type.setter
    def background_image_crop_type(self, background_image_crop_type):
        """
        Sets the background_image_crop_type.

        Gets or sets the background image crop type of signature  # noqa: E501

        :param background_image_crop_type: The background_image_crop_type.  # noqa: E501
        :type: str
        """
        if background_image_crop_type is None:
            raise ValueError("Invalid value for `background_image_crop_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "OuterArea", "MiddleArea", "InnerArea"]  # noqa: E501
        if not background_image_crop_type.isdigit():	
            if background_image_crop_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `background_image_crop_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(background_image_crop_type, allowed_values))
            self._background_image_crop_type = background_image_crop_type
        else:
            self._background_image_crop_type = allowed_values[int(background_image_crop_type) if six.PY3 else long(background_image_crop_type)]

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignStampOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="TestFile.py">
#   Copyright (c) 2019 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
from __future__ import absolute_import

from groupdocs_signature_cloud import FileInfo
""" 
    Describes file for tests.
"""
class TestFile(object):

    @classmethod
    def pdf_one_page(cls):
        f = TestFile()
        f.file_name = "01_pages.pdf"
        f.folder = "Pdf\\"
        return f

    @classmethod
    def image_jpg(cls):
        f = TestFile()
        f.file_name = "01_pages.jpg"
        f.folder = "Images\\"
        return f  

    @classmethod
    def presentation_pptx(cls):
        f = TestFile()
        f.file_name = "01_pages.pptx"
        f.folder = "Presentations\\"
        return f           

    @classmethod
    def spreadsheet_xlsx(cls):
        f = TestFile()
        f.file_name = "01_pages.xlsx"
        f.folder = "Spreadsheets\\"
        return f  

    @classmethod
    def word_docx(cls):
        f = TestFile()
        f.file_name = "01_pages.docx"
        f.folder = "WordProcessing\\"
        return f  

    @classmethod
    def image_signed(cls):
        f = TestFile()
        f.file_name = "SignedForVerificationAll.png"
        f.folder = "Signed\\"
        f.size = 27533
        return f

    @classmethod
    def pdf_signed(cls):
        f = TestFile()
        f.file_name = "SignedForVerificationAll.pdf"
        f.folder = "Signed\\"
        f.size = 164060
        return f

    @classmethod
    def presentation_signed(cls):
        f = TestFile()
        f.file_name = "SignedForVerificationAll.pptx"
        f.folder = "Signed\\"
        f.size = 43205
        return f

    @classmethod
    def spreadsheet_signed(cls):
        f = TestFile()
        f.file_name = "SignedForVerificationAll.xlsx"
        f.folder = "Signed\\"
        f.size = 318157
        return f

    @classmethod
    def wordprocessing_signed(cls):
        f = TestFile()
        f.file_name = "SignedForVerificationAll.docx"
        f.folder = "Signed\\"
        f.size = 1358290
        return f

    @classmethod
    def additional_signature01(cls):
        f = TestFile()
        f.file_name = "signature_01.jpg"
        f.folder = "Additional\\"        
        return f

    @classmethod
    def additional_pfx(cls):
        f = TestFile()
        f.file_name = "SherlockHolmes.pfx"
        f.folder = "Additional\\"        
        return f   

    @classmethod
    def image_sign(cls):
        f = TestFile()
        f.file_name = "JohnSmithSign.png"
        f.folder = "Additional\\"        
        return f   
    
    @classmethod
    def not_exist(cls):
        f = TestFile()
        f.file_name = "not-exist.docx"
        f.folder = "somefolder\\"
        return f

    @classmethod
    def get_test_files(cls):
        return [
            cls.pdf_one_page(),
            cls.image_jpg(),
            cls.presentation_pptx(),
            cls.spreadsheet_xlsx(),
            cls.word_docx(),
            cls.image_signed(),
            cls.pdf_signed(),
            cls.presentation_signed(),
            cls.spreadsheet_signed(),
            cls.wordprocessing_signed(),
            cls.additional_signature01(),
            cls.additional_pfx(),
            cls.image_sign()
        ]

    def FilePath(self):
        return self.folder + self.file_name

    def ToFileInfo(self):
        f = FileInfo()
        f.file_path = self.folder + self.file_name
        if hasattr(self, 'password'):
            f.password = self.password
        return f        


# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PdfTextAnnotationAppearance.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignatureAppearance

class PdfTextAnnotationAppearance(SignatureAppearance):
    """
    Describes appearance of PDF text annotation object (Title, Subject, Content).
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'border': 'BorderLine',
        'border_effect': 'str',
        'border_effect_intensity': 'int',
        'contents': 'str',
        'h_corner_radius': 'int',
        'subject': 'str',
        'title': 'str',
        'v_corner_radius': 'int'
    }

    attribute_map = {
        'border': 'Border',
        'border_effect': 'BorderEffect',
        'border_effect_intensity': 'BorderEffectIntensity',
        'contents': 'Contents',
        'h_corner_radius': 'HCornerRadius',
        'subject': 'Subject',
        'title': 'Title',
        'v_corner_radius': 'VCornerRadius'
    }

    def __init__(self, border=None, border_effect=None, border_effect_intensity=None, contents=None, h_corner_radius=None, subject=None, title=None, v_corner_radius=None, **kwargs):  # noqa: E501
        """Initializes new instance of PdfTextAnnotationAppearance"""  # noqa: E501

        self._border = None
        self._border_effect = None
        self._border_effect_intensity = None
        self._contents = None
        self._h_corner_radius = None
        self._subject = None
        self._title = None
        self._v_corner_radius = None

        if border is not None:
            self.border = border
        if border_effect is not None:
            self.border_effect = border_effect
        if border_effect_intensity is not None:
            self.border_effect_intensity = border_effect_intensity
        if contents is not None:
            self.contents = contents
        if h_corner_radius is not None:
            self.h_corner_radius = h_corner_radius
        if subject is not None:
            self.subject = subject
        if title is not None:
            self.title = title
        if v_corner_radius is not None:
            self.v_corner_radius = v_corner_radius

        base = super(PdfTextAnnotationAppearance, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def border(self):
        """
        Gets the border.  # noqa: E501

        Represents border appearance  # noqa: E501

        :return: The border.  # noqa: E501
        :rtype: BorderLine
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border.

        Represents border appearance  # noqa: E501

        :param border: The border.  # noqa: E501
        :type: BorderLine
        """
        self._border = border
    
    @property
    def border_effect(self):
        """
        Gets the border_effect.  # noqa: E501

        Gets or sets border effect.  # noqa: E501

        :return: The border_effect.  # noqa: E501
        :rtype: str
        """
        return self._border_effect

    @border_effect.setter
    def border_effect(self, border_effect):
        """
        Sets the border_effect.

        Gets or sets border effect.  # noqa: E501

        :param border_effect: The border_effect.  # noqa: E501
        :type: str
        """
        if border_effect is None:
            raise ValueError("Invalid value for `border_effect`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Cloudy"]  # noqa: E501
        if not border_effect.isdigit():	
            if border_effect not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_effect` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_effect, allowed_values))
            self._border_effect = border_effect
        else:
            self._border_effect = allowed_values[int(border_effect) if six.PY3 else long(border_effect)]
    
    @property
    def border_effect_intensity(self):
        """
        Gets the border_effect_intensity.  # noqa: E501

        Gets or sets border effect intensity. Valid range of value is [0..2].  # noqa: E501

        :return: The border_effect_intensity.  # noqa: E501
        :rtype: int
        """
        return self._border_effect_intensity

    @border_effect_intensity.setter
    def border_effect_intensity(self, border_effect_intensity):
        """
        Sets the border_effect_intensity.

        Gets or sets border effect intensity. Valid range of value is [0..2].  # noqa: E501

        :param border_effect_intensity: The border_effect_intensity.  # noqa: E501
        :type: int
        """
        if border_effect_intensity is None:
            raise ValueError("Invalid value for `border_effect_intensity`, must not be `None`")  # noqa: E501
        self._border_effect_intensity = border_effect_intensity
    
    @property
    def contents(self):
        """
        Gets the contents.  # noqa: E501

        Gets or sets content of annotation object.  # noqa: E501

        :return: The contents.  # noqa: E501
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents.

        Gets or sets content of annotation object.  # noqa: E501

        :param contents: The contents.  # noqa: E501
        :type: str
        """
        self._contents = contents
    
    @property
    def h_corner_radius(self):
        """
        Gets the h_corner_radius.  # noqa: E501

        Gets or sets horizontal corner radius.  # noqa: E501

        :return: The h_corner_radius.  # noqa: E501
        :rtype: int
        """
        return self._h_corner_radius

    @h_corner_radius.setter
    def h_corner_radius(self, h_corner_radius):
        """
        Sets the h_corner_radius.

        Gets or sets horizontal corner radius.  # noqa: E501

        :param h_corner_radius: The h_corner_radius.  # noqa: E501
        :type: int
        """
        if h_corner_radius is None:
            raise ValueError("Invalid value for `h_corner_radius`, must not be `None`")  # noqa: E501
        self._h_corner_radius = h_corner_radius
    
    @property
    def subject(self):
        """
        Gets the subject.  # noqa: E501

        Gets or sets Subject representing description of the object.  # noqa: E501

        :return: The subject.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject.

        Gets or sets Subject representing description of the object.  # noqa: E501

        :param subject: The subject.  # noqa: E501
        :type: str
        """
        self._subject = subject
    
    @property
    def title(self):
        """
        Gets the title.  # noqa: E501

        Gets or sets a Title that will be displayed in title bar of annotation object.  # noqa: E501

        :return: The title.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title.

        Gets or sets a Title that will be displayed in title bar of annotation object.  # noqa: E501

        :param title: The title.  # noqa: E501
        :type: str
        """
        self._title = title
    
    @property
    def v_corner_radius(self):
        """
        Gets the v_corner_radius.  # noqa: E501

        Gets or sets vertical corner radius.  # noqa: E501

        :return: The v_corner_radius.  # noqa: E501
        :rtype: int
        """
        return self._v_corner_radius

    @v_corner_radius.setter
    def v_corner_radius(self, v_corner_radius):
        """
        Sets the v_corner_radius.

        Gets or sets vertical corner radius.  # noqa: E501

        :param v_corner_radius: The v_corner_radius.  # noqa: E501
        :type: int
        """
        if v_corner_radius is None:
            raise ValueError("Invalid value for `v_corner_radius`, must not be `None`")  # noqa: E501
        self._v_corner_radius = v_corner_radius

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfTextAnnotationAppearance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import os

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestSignImage(TestContext):

    def test_sign_image_image(self):
        test_file = TestFile.image_jpg()
        signedFileName = "Output\\ImageImageSigned.jpg"        
        settings = self.populate_sign_options(signedFileName, test_file)            
        response = self.sign_api.create_signatures(CreateSignaturesRequest(settings))
        self.check_response(response, signedFileName)

    def test_sign_image_pdf(self):
        test_file = TestFile.pdf_one_page()
        signedFileName = "Output\\PdfImageSigned.pdf"        
        settings = self.populate_sign_options(signedFileName, test_file)            
        response = self.sign_api.create_signatures(CreateSignaturesRequest(settings))
        self.check_response(response, signedFileName)

    def test_sign_image_presentation(self):
        test_file = TestFile.presentation_pptx()
        signedFileName = "Output\\PresentationImageSigned.pptx"        
        settings = self.populate_sign_options(signedFileName, test_file)            
        response = self.sign_api.create_signatures(CreateSignaturesRequest(settings))
        self.check_response(response, signedFileName)

    def test_sign_image_spreadsheet(self):
        test_file = TestFile.spreadsheet_xlsx()
        signedFileName = "Output\\SpreadsheetImageSigned.xlsx"        
        settings = self.populate_sign_options(signedFileName, test_file)            
        response = self.sign_api.create_signatures(CreateSignaturesRequest(settings))
        self.check_response(response, signedFileName)

    def test_sign_image_wordprocessing(self):
        test_file = TestFile.word_docx()
        signedFileName = "Output\\WordImageSigned.docx"        
        settings = self.populate_sign_options(signedFileName, test_file)            
        response = self.sign_api.create_signatures(CreateSignaturesRequest(settings))
        self.check_response(response, signedFileName)                       

    @staticmethod
    def populate_sign_options(signedFileName, testFile):
        opts = SignImageOptions()        
        
        # set signature properties
        opts.signature_type = 'Image'
        opts.image_file_path = TestFile.image_sign().FilePath()

        # set signature position on a page
        opts.left = 100
        opts.top = 100
        opts.width = 200
        opts.height = 100
        opts.location_measure_type = "Pixels"
        opts.size_measure_type = "Pixels"        
        opts.rotation_angle = 0
        opts.horizontal_alignment = "None"
        opts.vertical_alignment = "None"
        opts.margin = Padding()
        opts.margin.all = 5
        opts.margin_measure_type = "Pixels"

        # set signature appearance
        opts.transparency = 0.8

        opts.page = 1
        opts.all_pages = False
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps

        settings = SignSettings()
        settings.file_info = testFile.ToFileInfo()
        settings.options = [opts]
        settings.save_options = SaveOptions()
        settings.save_options.output_file_path = signedFileName
        return settings
    
    def check_response(self, response, signedFileName):
        self.assertTrue(response)
        self.assertTrue(response.file_info)
        self.assertEqual(response.file_info.file_path, signedFileName)
        # Check signed file
        request = ObjectExistsRequest(signedFileName)        
        data = self.storage_api.object_exists(request)
        self.assertTrue(data.exists)         


if __name__ == '__main__':
    unittest.main()
